@@ -4,6 +4,7 @@ import os
 import logging
 import time
 import json
+import re
 from requests_toolbelt import MultipartEncoder
 from bs4 import BeautifulSoup
 try:
@@ -113,13 +114,13 @@ class API:
                   'view=permalink&id=%s'%str(post_id)
         req = self.session.get(url)
         soup = BeautifulSoup(req.text,'lxml')
-        post_content = soup.find('div',class_='z')
-        author = post_content.find('h3').text
-        content_lines = post_content.find('div', {'data-ft':'{"tn":"*s"}'}).findAll('p')
-        content = ''
-        for content_line in content_lines:
-            content += content_line.text
-            content += '\n'
+        post_content = soup.find('div',id='m_story_permalink_view')
+        author = post_content.find('h3', recursive=True).text
+        content = str(post_content.find('div', {'data-ft':'{"tn":"*s"}'}))
+        content = content.replace('<br/> ', '\n')
+        content = content.replace('<br/>', '\n')
+        content = re.sub('<[^>]+> ', '', content)
+        content = re.sub('<[^>]+>', '', content)
         time = post_content.find('footer').find('abbr').text
         post_info = data_type.PostInfo(post_id,
                                        author,
